=======
Credits
=======

Development Lead
----------------

* Mélanie Cambus

* Marc-Olivier Buob

* Fabien Mathieu <fabien.mathieu@normalesup.org>

Contributors
------------

None yet. Why not be the first?
